@@ -22,12 +22,6 @@ def main_options(parser):
     from auto_editor.utils.types import (file_type, float_type, sample_rate_type,
         frame_type, range_type, speed_range_type, block_type, margin_type, color_type)
 
-    parser.add_text('Progress Options')
-    parser.add_argument('--machine-readable-progress', action='store_true',
-        help='Set progress bar that is easier to parse.')
-    parser.add_argument('--no-progress', action='store_true',
-        help='Do not display any progress at all.')
-
     parser.add_text('Object Options')
     parser.add_argument('--add-text', nargs='*', dataclass=TextObject,
         help='Add a text object to the timeline.')
@@ -57,14 +51,11 @@ def main_options(parser):
             'This option only works on YouTube URLs, or where `--id` points to a valid '
             'YouTube ID.\n\nCategories include: '
             'sponsor intro outro selfpromo interaction music_offtopic')
-
     parser.add_argument('--download-archive', type=file_type, default=None,
         help='Download only videos not listed in archive file. Record the IDs of'
              ' all downloads.')
     parser.add_argument('--cookies', type=file_type, default=None,
         help='The file to read cookies from and dump the cookie jar in.')
-    parser.add_argument('--check-certificate', action='store_true',
-        help='Check the website certificate before downloading.')
 
     parser.add_text('Motion Detection Options')
     parser.add_argument('--motion-threshold', type=float_type, default=0.02,
@@ -77,16 +68,16 @@ def main_options(parser):
         help='Set the strength of the blur applied to a frame before being compared.')
 
     parser.add_text('Exporting as Media Options')
+    parser.add_argument('--video-codec', '-vcodec', '-c:v', default='auto',
+        help='Set the video codec for the output media file.')
+    parser.add_argument('--audio-codec', '-acodec', '-c:a', default='auto',
+        help='Set the audio codec for the output media file.')
     parser.add_argument('--video-bitrate', '-b:v', default='10m',
         help='Set the number of bits per second for video.')
     parser.add_argument('--audio-bitrate', '-b:a', default='unset',
         help='Set the number of bits per second for audio.')
     parser.add_argument('--sample-rate', '-ar', type=sample_rate_type,
         help='Set the sample rate of the input and output videos.')
-    parser.add_argument('--video-codec', '-vcodec', '-c:v', default='auto',
-        help='Set the video codec for the output media file.')
-    parser.add_argument('--audio-codec', '-acodec', '-c:a', default='auto',
-        help='Set the audio codec for the output media file.')
     parser.add_argument('--preset', '-preset', default='unset',
         choices=['ultrafast', 'superfast', 'veryfast', 'faster', 'fast', 'medium',
             'slow', 'slower', 'veryslow', 'unset'],
@@ -96,18 +87,24 @@ def main_options(parser):
             'zerolatency', 'none', 'unset'],
         help='Set the tune for ffmpeg to compress video better in certain circumstances.')
     parser.add_argument('--constant-rate-factor', '-crf', default='unset', range='0 to 51',
-        help='Set the quality for video using the crf method.')
+        help='Set a value to the ffmpeg option -crf.',
+        manual="This option's value gets directly passed to the -crf flag used by ffmpeg "
+        "during encoding. If the video encoder does not support crf, "
+        "the program will error.")
     parser.add_argument('--video-quality-scale', '-qscale:v', '-q:v', default='unset',
         range='1 to 31',
         help='Set a value to the ffmpeg option -qscale:v')
     parser.add_argument('--scale', type=float_type, default=1,
-        help='Scale the output media file by a certain factor.')
+        help='Scale the output video by a certain factor.')
 
     parser.add_text('Miscellaneous Options')
     parser.add_argument('--background', type=color_type, default='#000',
         help='Set the color of the background that is visible when the video is moved.')
     parser.add_argument('--combine-files', action='store_true',
         help='Combine all input files into one before editing.')
+    parser.add_argument('--progress', default='modern',
+        choices=['modern', 'classic', 'ascii', 'machine', 'none'],
+        help='Set what type of progress bar to use.')
 
     parser.add_text('Manual Editing Options')
     parser.add_argument('--cut-out', type=range_type, nargs='*',
@@ -222,7 +219,7 @@ def main_options(parser):
         help='Set the minimum length a clip can be. If a clip is too short, cut it.')
     parser.add_argument('--min-cut-length', '-mcut', type=frame_type, default=6,
         range='0 to Infinity',
-        help="Set the minimum length a cut can be. If a cut is too short, don't cut")
+        help="Set the minimum length a cut can be. If a cut is too short, don't cut.")
 
     parser.add_blank()
     parser.add_argument('--help', '-h', action='store_true',
@@ -230,13 +227,10 @@ def main_options(parser):
 
     parser.add_argument('--output-file', '--output', '-o', nargs='*',
         help='Set the name(s) of the new output.')
-    parser.add_argument('input', nargs='*',
+    parser.add_blank()
+    parser.add_required('input', nargs='*',
         help='File(s) or URL(s) that will be edited.')
 
-    parser.add_text('Have an issue? Make an issue. Visit:\n '
-        '    https://github.com/wyattblue/auto-editor/issues')
-    parser.add_text('The help option can be used on a specific option:\n '
-        '    auto-editor --frame-margin --help')
     return parser
 
 
@@ -253,7 +247,7 @@ def main():
 
     subcommands = ['create', 'test', 'info', 'levels', 'grep', 'subdump', 'desc']
 
-    if(len(sys.argv) > 1 and sys.argv[1] in subcommands):
+    if len(sys.argv) > 1 and sys.argv[1] in subcommands:
         obj = __import__('auto_editor.subcommands.{}'.format(sys.argv[1]),
             fromlist=['subcommands'])
         obj.main(sys.argv[2:])
@@ -275,43 +269,43 @@ def main():
 
     ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, args.show_ffmpeg_debug)
 
-    if(args.debug and args.input == []):
+    if args.debug and args.input == []:
         import platform
 
-        print('Python Version: {} {}'.format(platform.python_version(), is64bit))
-        print('Platform: {} {} {}'.format(platform.system(), platform.release(), platform.machine().lower()))
-        print('FFmpeg path: {}'.format(ffmpeg.path))
-        print('FFmpeg version: {}'.format(ffmpeg.version))
-        print('Auto-Editor version {}'.format(auto_editor.version))
+        print(f'Python Version: {platform.python_version()} {is64bit}')
+        print(f'Platform: {platform.system()} {platform.release()} {platform.machine().lower()}')
+        print(f'FFmpeg Version: {ffmpeg.version}')
+        print(f'FFmpeg Path: {ffmpeg.path}')
+        print(f'Auto-Editor Version: {auto_editor.version}')
         sys.exit()
 
-    if(is64bit == '32-bit'):
+    if is64bit == '32-bit':
         Log().warning('You have the 32-bit version of Python, which may lead to '
             'memory crashes.')
 
-    if(args.version):
-        print('Auto-Editor version {}'.format(auto_editor.version))
+    if args.version:
+        print(f'Auto-Editor version {auto_editor.version}')
         sys.exit()
 
-    if(args.temp_dir is None):
+    if args.temp_dir is None:
         TEMP = tempfile.mkdtemp()
     else:
         TEMP = args.temp_dir
-        if(os.path.isfile(TEMP)):
+        if os.path.isfile(TEMP):
             Log().error('Temp directory cannot be an already existing file.')
-        if(os.path.isdir(TEMP)):
-            if(len(os.listdir(TEMP)) != 0):
+        if os.path.isdir(TEMP):
+            if len(os.listdir(TEMP)) != 0:
                 Log().error('Temp directory should be empty!')
         else:
             os.mkdir(TEMP)
 
-    if(args.timeline):
+    if args.timeline:
         args.quiet = True
 
     log = Log(args.debug, args.quiet, temp=TEMP)
-    log.debug('Temp Directory: {}'.format(TEMP))
+    log.debug(f'Temp Directory: {TEMP}')
 
-    if(args.input == []):
+    if args.input == []:
         log.error('You need to give auto-editor an input file or folder so it can '
             'do the work for you.')
 
@@ -319,51 +313,51 @@ def main():
         args.export_to_shotcut, args.export_as_clip_sequence].count(True) > 1):
         log.error('You must choose only one export option.')
 
-    if(args.constant_rate_factor != 'unset'):
-        if(int(args.constant_rate_factor) < 0 or int(args.constant_rate_factor) > 51):
+    if args.constant_rate_factor != 'unset':
+        if int(args.constant_rate_factor) < 0 or int(args.constant_rate_factor) > 51:
             log.error('Constant rate factor (crf) must be between 0-51.')
-    if(args.md_width < 1):
+    if args.md_width < 1:
         log.error('--md-width cannot be less than 1.')
 
-    def write_starting_message(args):
-        if(args.export_to_premiere):
-            return 'Exporting to Adobe Premiere Pro XML file.'
-        if(args.export_to_final_cut_pro):
-            return 'Exporting to Final Cut Pro XML file.'
-        if(args.export_to_shotcut):
-            return 'Exporting to Shotcut XML Timeline file.'
-        if(args.export_as_audio):
-            return 'Exporting as audio.'
-        return 'Starting.'
+    def write_starting_message(args) -> str:
+        if args.export_to_premiere:
+            return 'Exporting to Adobe Premiere Pro XML file'
+        if args.export_to_final_cut_pro:
+            return 'Exporting to Final Cut Pro XML file'
+        if args.export_to_shotcut:
+            return 'Exporting to Shotcut XML Timeline file'
+        if args.export_as_audio:
+            return 'Exporting as audio'
+        return 'Starting'
 
-    if(not args.preview and not args.timeline):
+    if not args.preview and not args.timeline:
         log.conwrite(write_starting_message(args))
 
-    if(args.preview or args.timeline or args.export_as_clip_sequence or making_data_file):
+    if args.preview or args.timeline or args.export_as_clip_sequence or making_data_file:
         args.no_open = True
 
-    if(args.md_blur < 0):
+    if args.md_blur < 0:
         args.md_blur = 0
 
-    if(args.silent_speed <= 0 or args.silent_speed > 99999):
+    if args.silent_speed <= 0 or args.silent_speed > 99999:
         args.silent_speed = 99999
 
-    if(args.video_speed <= 0 or args.video_speed > 99999):
+    if args.video_speed <= 0 or args.video_speed > 99999:
         args.video_speed = 99999
 
-    if(args.output_file is None):
+    if args.output_file is None:
         args.output_file = []
 
     from auto_editor.validate_input import valid_input
     input_list, segments = valid_input(args.input, ffmpeg, args, log)
 
-    if(len(args.output_file) < len(input_list)):
+    if len(args.output_file) < len(input_list):
         for i in range(len(input_list) - len(args.output_file)):
             args.output_file.append(set_output_name(input_list[i], None,
                 making_data_file, args))
 
-    if(args.combine_files):
-        if(exporting_to_editor):
+    if args.combine_files:
+        if exporting_to_editor:
             temp_file = 'combined.mp4'
         else:
             temp_file = os.path.join(TEMP, 'combined.mp4')
@@ -380,22 +374,22 @@ def main():
     def main_loop(input_list, ffmpeg, args, segments, log):
         num_cuts = 0
 
-        progress = ProgressBar(args.machine_readable_progress, args.no_progress)
+        progress = ProgressBar(args.progress)
 
         for i, input_path in enumerate(input_list):
             inp = ffmpeg.file_info(input_path)
 
-            if(len(input_list) > 1):
-                log.conwrite('Working on {}'.format(inp.basename))
+            if len(input_list) > 1:
+                log.conwrite(f'Working on {inp.basename}')
 
             cuts, output_path = edit_media(i, inp, ffmpeg, args, progress,
                 segments[i], exporting_to_editor, making_data_file, TEMP, log)
             num_cuts += cuts
 
-        if(not args.preview and not args.timeline and not making_data_file):
+        if not args.preview and not args.timeline and not making_data_file:
             timer.stop()
 
-        if(not args.preview and not args.timeline and making_data_file):
+        if not args.preview and not args.timeline and making_data_file:
             # Assume making each cut takes about 30 seconds.
             time_save = usefulfunctions.human_readable_time(num_cuts * 30)
             s = 's' if num_cuts != 1 else ''
@@ -403,7 +397,7 @@ def main():
             log.print('Auto-Editor made {} cut{}, which would have taken about {} if '
                 'edited manually.'.format(num_cuts, s, time_save))
 
-        if(not args.no_open):
+        if not args.no_open:
             usefulfunctions.open_with_system_default(output_path, log)
 
     try:
@@ -412,5 +406,5 @@ def main():
         log.error('Keyboard Interrupt')
     log.cleanup()
 
-if(__name__ == '__main__'):
+if __name__ == '__main__':
     main()
