@@ -6,11 +6,9 @@ import os
 import sys
 import json
 
-from typing import Tuple, List
 from auto_editor.utils.log import Log
 
-def read_json_timeline(json_file, log):
-    # type: (str, Log) -> Tuple[str, str, List[Tuple[int, int, float]]]
+def read_json_timeline(json_file: str, log: Log):
     with open(json_file, 'r') as f:
         data = json.load(f)
 
@@ -24,7 +22,6 @@ def read_json_timeline(json_file, log):
 
 
 def make_json_timeline(media_file, out, obj_sheet, chunks, fps, background, log):
-    # type: (str, str | int, List[Tuple[int, int, float]], Log) -> None
     data = {
         'version': '0.2.0',
         'source': os.path.abspath(media_file),
