@@ -3,15 +3,16 @@ import sys
 def levels_options(parser):
     parser.add_argument('--kind', type=str, default='audio')
     parser.add_argument('--track', type=int, default=0,
-        help='what audio/video track to get. If --kind is set to motion, track will look at video streams.')
+        help='Select the track to get. If `--kind` is set to motion, track will look '
+            'at video tracks instead of audio.')
     parser.add_argument('--ffmpeg-location', default=None,
-        help='point to your custom ffmpeg file.')
+        help='Point to your custom ffmpeg file.')
     parser.add_argument('--my-ffmpeg', action='store_true',
-        help='use the ffmpeg on your PATH instead of the one packaged.')
+        help='Use the ffmpeg on your PATH instead of the one packaged.')
     parser.add_argument('--help', '-h', action='store_true',
-        help='print info about the program or an option and exit.')
-    parser.add_argument('input', nargs='*',
-        help='the template')
+        help='Print info about the program or an option and exit.')
+    parser.add_required('input', nargs='*',
+        help='Path to the file to have its levels dumped.')
     return parser
 
 def main(sys_args=sys.argv[1:]):
