@@ -3,18 +3,16 @@ To prevent duplicate code being pasted between scripts, common functions should
 put here. No function should modify or create video/audio files on its own.
 """
 
-from typing import List, Tuple
+from typing import List, Tuple, Union
+from auto_editor.utils.log import Log
 
-def get_stdout(cmd):
-    # type: (List[str]) -> str
-    import subprocess
-    process = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-        stderr=subprocess.STDOUT)
-    stdout, __ = process.communicate()
+def get_stdout(cmd: List[str]) -> str:
+    from subprocess import Popen, PIPE, STDOUT
+
+    stdout, _ = Popen(cmd, stdout=PIPE, stderr=STDOUT).communicate()
     return stdout.decode()
 
-def clean_list(x, rm_chars):
-    # type: (list, str) -> list
+def clean_list(x: List[str], rm_chars: str) -> list:
     new_list = []
     for item in x:
         for char in rm_chars:
@@ -22,9 +20,8 @@ def clean_list(x, rm_chars):
         new_list.append(item)
     return new_list
 
-def aspect_ratio(width, height):
-    # type: (int, int) -> Tuple[int, int] | Tuple[None, None]
-    if(height == 0):
+def aspect_ratio(width: int, height: int) -> Union[Tuple[int, int], Tuple[None, None]]:
+    if height == 0:
         return None, None
 
     def gcd(a, b):
@@ -35,32 +32,29 @@ def aspect_ratio(width, height):
     c = gcd(width, height)
     return width // c, height // c
 
-def get_new_length(chunks, fps):
-    # type: (List[Tuple[int, int, float]], float) -> float
+def get_new_length(chunks: List[Tuple[int, int, float]], fps: float) -> float:
     time_in_frames = 0.0
     for chunk in chunks:
         leng = chunk[1] - chunk[0]
-        if(chunk[2] < 99999):
+        if chunk[2] != 99999:
             time_in_frames += leng * (1 / chunk[2])
     return time_in_frames / fps
 
-def human_readable_time(time_in_secs):
-    # type(int | float) -> str
+def human_readable_time(time_in_secs: Union[int, float]) -> str:
     units = 'seconds'
-    if(time_in_secs >= 3600):
+    if time_in_secs >= 3600:
         time_in_secs = round(time_in_secs / 3600, 1)
-        if(time_in_secs % 1 == 0):
+        if time_in_secs % 1 == 0:
             time_in_secs = round(time_in_secs)
         units = 'hours'
-    if(time_in_secs >= 60):
+    if time_in_secs >= 60:
         time_in_secs = round(time_in_secs / 60, 1)
-        if(time_in_secs >= 10 or time_in_secs % 1 == 0):
+        if time_in_secs >= 10 or time_in_secs % 1 == 0:
             time_in_secs = round(time_in_secs)
         units = 'minutes'
     return '{} {}'.format(time_in_secs, units)
 
-def open_with_system_default(path, log):
-    # type(str, Log) -> None
+def open_with_system_default(path: str, log: Log) -> None:
     from subprocess import call
     try:  # should work on Windows
         from os import startfile
@@ -77,33 +71,33 @@ def open_with_system_default(path, log):
                 except Exception:
                     log.warning('Could not open output file.')
 
-def fnone(val):
-    # type: (...) -> bool
+def fnone(val: object) -> bool:
     return val == 'none' or val == 'unset' or val is None
 
-def append_filename(path, val):
-    # type: (str, str) -> str
-    import os.path
-    root, ext = os.path.splitext(path)
+def append_filename(path: str, val: str) -> str:
+    from os.path import splitext
+
+    root, ext = splitext(path)
     return root + val + ext
 
-def set_output_name(path, inp_ext, making_data_file, args):
-    # type: (...) -> str
-    import os.path
-    root, ext = os.path.splitext(path)
+def set_output_name(path: str, inp_ext: str, making_data_file: bool, args: object) -> str:
+    from os.path import splitext
 
-    if(args.export_as_json):
+    root, ext = splitext(path)
+
+    if args.export_as_json:
         return root + '.json'
-    if(args.export_to_final_cut_pro):
+    if args.export_to_final_cut_pro:
         return root + '.fcpxml'
-    if(args.export_to_shotcut):
+    if args.export_to_shotcut:
         return root + '.mlt'
-    if(making_data_file):
+    if making_data_file:
         return root + '.xml'
-    if(args.export_as_audio):
+    if args.export_as_audio:
         return root + '_ALTERED.wav'
-    if(ext == ''):
-        if(inp_ext is None):
+    if ext == '':
+        if inp_ext is None:
             return root
         return root + inp_ext
+
     return root + '_ALTERED' + ext
