@@ -7,11 +7,11 @@ from datetime import timedelta
 
 class Timer:
     __slots__ = ('start_time', 'quiet')
-    def __init__(self, quiet=False):
+    def __init__(self, quiet=False) -> None:
         self.start_time = perf_counter()
         self.quiet = quiet
 
-    def stop(self):
+    def stop(self) -> None:
         if not self.quiet:
             second_len = round(perf_counter() - self.start_time, 2)
             minute_len = timedelta(seconds=round(second_len))
@@ -20,7 +20,7 @@ class Timer:
 
 class Log:
     __slots__ = ('is_debug', 'quiet', 'temp')
-    def __init__(self, show_debug=False, quiet=False, temp=None):
+    def __init__(self, show_debug=False, quiet=False, temp=None) -> None:
         self.is_debug = show_debug
         self.quiet = quiet
         self.temp = temp
@@ -89,10 +89,3 @@ class Log:
     def print(self, message: str) -> None:
         if not self.quiet:
             sys.stdout.write(f'{message}\n')
-
-    def checkType(self, data, name, correct_type):
-        if not isinstance(data, correct_type):
-            badtype = type(data).__name__
-            goodtype = correct_type.__name__
-            self.bug('Variable "{}" was not a {}, but a {}'.format(
-                name, goodtype, badtype), 'bug report')
