@@ -1,16 +1,17 @@
 import os
 import re
 import sys
-from typing import Optional
+from typing import List, Tuple, Optional
 
 from auto_editor.utils.progressbar import ProgressBar
 from auto_editor.utils.log import Log
+from auto_editor.ffwrapper import FFmpeg
 
 
 class MyLogger:
     @staticmethod
     def debug(msg):
-        print(msg)
+        pass
 
     @staticmethod
     def warning(msg):
@@ -34,7 +35,7 @@ def parse_bytes(bytestr) -> Optional[int]:
     return round(number * multiplier)
 
 
-def sponsor_block_api(_id: str, categories: list, log: Log) -> Optional[dict]:
+def sponsor_block_api(_id: str, categories: List[str], log: Log) -> Optional[dict]:
     from urllib import request
     from urllib.error import HTTPError
     import json
@@ -52,21 +53,17 @@ def sponsor_block_api(_id: str, categories: list, log: Log) -> Optional[dict]:
         return None
 
 
-def download_video(my_input, args, ffmpeg, log: Log):
+def download_video(my_input: str, args, ffmpeg: FFmpeg, log: Log) -> str:
     log.conwrite('Downloading video...')
-    if '@' in my_input:
-        res = my_input[my_input.index('@') + 1 :]
-        if ' ' in res:
-            res = res[: res.index(' ')]
-        res = res.strip()
+    if ' @' in my_input:
+        max_height = my_input[my_input.index(' @') + 2 :].strip()
+        download_format = f'bestvideo[ext=mp4][height<={max_height}]+bestaudio[ext=m4a]'
+
         my_input = my_input[: my_input.index(' ')]
     else:
-        res = '720'
+        download_format = 'bestvideo[ext=mp4]+bestaudio[ext=m4a]'
 
-    outtmpl = re.sub(r'\W+', '-', my_input)
-    if outtmpl.endswith('-mp4'):
-        outtmpl = outtmpl[:-4]
-    outtmpl += '.mp4'
+    outtmpl = re.sub(r'\W+', '-', os.path.splitext(my_input)[0]) + '.mp4'
 
     if args.download_dir is not None:
         outtmpl = os.path.join(args.download_dir, outtmpl)
@@ -77,22 +74,22 @@ def download_video(my_input, args, ffmpeg, log: Log):
         log.import_error('yt-dlp')
 
     if not os.path.isfile(outtmpl):
-        ytbar = ProgressBar(100, 'Downloading')
+        ytbar = ProgressBar(args.progress)
+        ytbar.start(100, 'Downloading')
 
-        def my_hook(d):
+        def my_hook(d: dict) -> None:
             if d['status'] == 'downloading':
                 ytbar.tick(float(d['_percent_str'].replace('%', '')))
 
-        def abspath(path):
+        def abspath(path: Optional[str]) -> Optional[str]:
             if path is None:
                 return None
             return os.path.abspath(path)
 
         ydl_opts = {
-            'nocheckcertificate': not args.check_certificate,
             'outtmpl': outtmpl,
             'ffmpeg_location': ffmpeg.path,
-            'format': f'bestvideo[ext=mp4][height<={res}]+bestaudio[ext=m4a]',
+            'format': download_format,
             'ratelimit': parse_bytes(args.limit_rate),
             'logger': MyLogger(),
             'cookiefile': abspath(args.cookies),
@@ -119,7 +116,7 @@ def download_video(my_input, args, ffmpeg, log: Log):
     return outtmpl
 
 
-def get_segment(args, my_input, log: Log):
+def get_segment(args, my_input: str, log: Log) -> Optional[dict]:
     if args.block is not None:
         if args.id is not None:
             return sponsor_block_api(args.id, args.block, log)
@@ -132,7 +129,10 @@ def get_segment(args, my_input, log: Log):
     return None
 
 
-def valid_input(inputs, ffmpeg, args, log: Log):
+def valid_input(
+    inputs: List[str], ffmpeg: FFmpeg, args, log: Log
+    ) -> Tuple[List[str], List[Optional[dict]]]:
+
     new_inputs = []
     segments = []
     for my_input in inputs:
